# ♆ NEPTUNE

**NEPTUNE** is a set of decoupled **Python libraries** intended to facilitate Python development:

* nconnect,
* nfin,
* nformat,
* ngui,
* nlearn,
* nmath,
* nserve, and
* nutil.

The library **nconnect** contains connectivity utility functions; among them:

* time series manipulation and
* pricing engine (including Black-Scholes model).

NEPTUNE is based on popular libraries like numpy, pandas, plotly and scipy.

---

## 🚀 Installation

Launch the following commands in a shell:
```bash
git clone https://github.com/b-io/io.barras.git
cd io.barras/python/neptune/
mvn clean install
```

---

## 📄 License

The libraries are released under the [MIT License](LICENSE).  
You are free to download, use, and share suggestions — contribute if you'd like to get involved.

[license]: <LICENSE>
